# FHIR utilities

This repository contains a set of utilities for working with FHIR resources.

## Installation

```bash
pip install fhir-utils
```

## Development

```bash
git clone https://github.com/prefeitura-rio/fhir-utils
cd fhir-utils
poetry install
```
